cheesecake.model.System

Package cheesecake :: Module model :: Class System |
[hide private]
[frames] | no frames]

## Class System
source code

    object --+
             |
            System

Nested Classes | [hide private]
Class |
Module |
Package |
Function |
ModuleVistor |

Instance Methods | [hide private]
| __init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| _push(self, cls, name, docstring)
| handleDuplicate(self, obj) This is called when we see two objects with the same .fullName(), for example:
| _pop(self, cls)
| push(self, obj, node=None)
| pop(self, obj)
| pushClass(self, name, docstring)
| popClass(self)
| pushModule(self, name, docstring)
| popModule(self)
| pushFunction(self, name, docstring, func_called)
| popFunction(self)
| pushPackage(self, name, docstring)
| popPackage(self)
| report(self)
| _report(self, o, indent)
| resolveAlias(self, n)
| resolveAliases(self)
| warning(self, type, detail)
| objectsOfType(self, cls)
| finalStateComputations(self)
| recordBasesAndSubclasses(self)
| __getstate__(self)
| __setstate__(self, state)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### _push(self, cls, name, docstring) | source code

### handleDuplicate(self, obj) | source code
This is called when we see two objects with the same .fullName(), for example: class C: if something: def meth(self): implementation 1 else: def meth(self): implementation 2 The default is that the second definition "wins".

### _pop(self, cls) | source code

### push(self, obj, node=None) | source code

### pop(self, obj) | source code

### pushClass(self, name, docstring) | source code

### popClass(self) | source code

### pushModule(self, name, docstring) | source code

### popModule(self) | source code

### pushFunction(self, name, docstring, func_called) | source code

### popFunction(self) | source code

### pushPackage(self, name, docstring) | source code

### popPackage(self) | source code

### report(self) | source code

### _report(self, o, indent) | source code

### resolveAlias(self, n) | source code

### resolveAliases(self) | source code

### warning(self, type, detail) | source code

### objectsOfType(self, cls) | source code

### finalStateComputations(self) | source code

### recordBasesAndSubclasses(self) | source code

### __getstate__(self) | source code

### __setstate__(self, state) | source code